Crate kcr_csi_ceph_io

Crate kcr_csi_ceph_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the csi.ceph.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

csi.ceph.io/v1

  • CephConnection
  • ClientProfileMapping
  • ClientProfile
  • Driver
  • OperatorConfig

csi.ceph.io/v1alpha1

  • CephConnection
  • ClientProfileMapping
  • ClientProfile
  • Driver
  • OperatorConfig

Modules

v1
v1alpha1