OperatorConfigDriverSpecDefaultsControllerPlugin

Struct OperatorConfigDriverSpecDefaultsControllerPlugin 

pub struct OperatorConfigDriverSpecDefaultsControllerPlugin {
Show 14 fields pub affinity: Option<OperatorConfigDriverSpecDefaultsControllerPluginAffinity>, pub annotations: Option<BTreeMap<String, String>>, pub container_extra_args: Option<BTreeMap<String, Vec<String>>>, pub deployment_strategy: Option<OperatorConfigDriverSpecDefaultsControllerPluginDeploymentStrategy>, pub host_network: Option<bool>, pub image_pull_policy: Option<String>, pub labels: Option<BTreeMap<String, String>>, pub priority_class_name: Option<String>, pub privileged: Option<bool>, pub replicas: Option<i32>, pub resources: Option<OperatorConfigDriverSpecDefaultsControllerPluginResources>, pub service_account_name: Option<String>, pub tolerations: Option<Vec<OperatorConfigDriverSpecDefaultsControllerPluginTolerations>>, pub volumes: Option<Vec<OperatorConfigDriverSpecDefaultsControllerPluginVolumes>>,
}
Driver’s controller plugin configuration

Fields

affinity: Option<OperatorConfigDriverSpecDefaultsControllerPluginAffinity>

Pod’s affinity settings

annotations: Option<BTreeMap<String, String>>

Pod’s annotations

container_extra_args: Option<BTreeMap<String, Vec<String>>>

Extra arguments for containers in the controller plugin deployment. The key is the container name, the value is a list of CLI arguments. The operator will not override the default CLI argument values it’s setting. This is more for customizing what comes as default with cephcsi. Examples of container names: csi-rbdplugin, csi-provisioner, csi-attacher, csi-resizer, csi-snapshotter, csi-omap-generator, liveness-prometheus, etc.

deployment_strategy: Option<OperatorConfigDriverSpecDefaultsControllerPluginDeploymentStrategy>

DeploymentStrategy describes how to replace existing pods with new ones Default value is Recreate

host_network: Option<bool>

hostNetwork setting to be propagated to CSI controller plugin pods

image_pull_policy: Option<String>

To indicate the image pull policy to be applied to all the containers in the csi driver pods.

labels: Option<BTreeMap<String, String>>

Pod’s labels

priority_class_name: Option<String>

Pod’s user defined priority class name

privileged: Option<bool>

To enable logrotation for csi pods, Some platforms require controller plugin to run privileged, For example, OpenShift with SELinux restrictions requires the pod to be privileged to write to hostPath.

replicas: Option<i32>

Set replicas for controller plugin’s deployment. Defaults to 2

resources: Option<OperatorConfigDriverSpecDefaultsControllerPluginResources>

Resource requirements for controller plugin’s containers

service_account_name: Option<String>

Service account name to be used for driver’s pods

tolerations: Option<Vec<OperatorConfigDriverSpecDefaultsControllerPluginTolerations>>

Pod’s tolerations list

volumes: Option<Vec<OperatorConfigDriverSpecDefaultsControllerPluginVolumes>>

Volume and volume mount definitions to attach to the pod