OperatorConfigDriverSpecDefaultsNodePluginResourcesAddons

Struct OperatorConfigDriverSpecDefaultsNodePluginResourcesAddons 

pub struct OperatorConfigDriverSpecDefaultsNodePluginResourcesAddons {
    pub claims: Option<Vec<OperatorConfigDriverSpecDefaultsNodePluginResourcesAddonsClaims>>,
    pub limits: Option<BTreeMap<String, IntOrString>>,
    pub requests: Option<BTreeMap<String, IntOrString>>,
}
ResourceRequirements describes the compute resource requirements.

Fields

claims: Option<Vec<OperatorConfigDriverSpecDefaultsNodePluginResourcesAddonsClaims>>

Claims lists the names of resources, defined in spec.resourceClaims, that are used by this container.

This field depends on the DynamicResourceAllocation feature gate.

This field is immutable. It can only be set for containers.

limits: Option<BTreeMap<String, IntOrString>>

Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/

requests: Option<BTreeMap<String, IntOrString>>

Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. Requests cannot exceed Limits. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/