This crate contains kube-rs compatible bindings for Kubernetes custom resources for the csi.ceph.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
csi.ceph.io/v1
CephConnectionClientProfileMappingClientProfileDriverOperatorConfig
csi.ceph.io/v1alpha1
CephConnectionClientProfileMappingClientProfileDriverOperatorConfig